CompOperator

Enum CompOperator 

pub enum CompOperator {
    Equals,
    NotEquals,
    GreaterThan,
    LessThan,
    GreaterOrEqual,
    LessOrEqual,
}
Represents a comparison operator which is used to filter out individual rolls of a dice roll

Variants



Equals

Represents the equality comparison (roll == expr)



NotEquals

Represents the inequality comparison (roll != expr)



GreaterThan

Represents the “greater than” comparison (roll > expr)



LessThan

Represents the “less then” comparison (roll < expr)



GreaterOrEqual

Represents the “greater than or equal to” comparison (roll >= expr)



LessOrEqual

Represents the “less than or equal to” comparison (roll <= expr)

Implementations

Source

impl CompOperator

pub fn eval<R: RangeRng>( self, dice_lhs: Operand, dice_rhs: Operand, compare_to: Operand, rand: &mut R, ) -> Operand

Use this function and the arguments provided to evaluate a comparison expression